@@ -25,7 +25,7 @@ namespace xeus
     XEUS_API
     int get_current_pid();
 
-    XEUS_API [[deprecated]]
+    [[deprecated]] XEUS_API 
     std::string get_cell_tmp_file(const std::string& prefix,
                                   int execution_count,
                                   const std::string& extension);
