@@ -30,8 +30,7 @@ namespace xeus
                                server_ptr server,
                                interpreter_ptr interpreter,
                                history_manager_ptr history_manager,
-                               debugger_ptr debugger,
-                               nl::json::error_handler_t eh)
+                               debugger_ptr debugger)
         : m_kernel_id(std::move(kernel_id))
         , m_user_name(std::move(user_name))
         , m_session_id(std::move(session_id))
@@ -43,7 +42,6 @@ namespace xeus
         , p_debugger(debugger)
         , m_parent_id({guid_list(0), guid_list(0)})
         , m_parent_header({nl::json::object(), nl::json::object()})
-        , m_error_handler(eh)
     {
         // Request handlers
         m_handler["execute_request"] = &xkernel_core::execute_request;
@@ -250,8 +248,8 @@ namespace xeus
 
             if (!silent && status == "error" && stop_on_error)
             {
-                long polling_interval = 50;
-                p_server->abort_queue(std::bind(&xkernel_core::abort_request, this, _1), 50);
+                constexpr long polling_interval = 50;
+                p_server->abort_queue(std::bind(&xkernel_core::abort_request, this, _1), polling_interval);
             }
         }
         catch (std::exception& e)
@@ -336,14 +334,14 @@ namespace xeus
         p_server->stop();
         nl::json reply;
         reply["restart"] = restart;
-        publish_message("shutdown", nl::json::object(), nl::json(reply), buffer_sequence(), channel::CONTROL);
+        publish_message("shutdown", nl::json::object(), std::move(reply), buffer_sequence(), channel::CONTROL);
         send_reply("shutdown_reply", nl::json::object(), std::move(reply), c);
     }
 
     void xkernel_core::interrupt_request(xmessage, channel c)
     {
         nl::json reply = nl::json::object();
-        publish_message("interrupt", nl::json::object(), nl::json(reply), buffer_sequence(), channel::CONTROL);
+        publish_message("interrupt", nl::json::object(), std::move(reply), buffer_sequence(), channel::CONTROL);
         send_reply("interrupt_reply", nl::json::object(), std::move(reply), c);
     }
 
