@@ -44,8 +44,7 @@ namespace xeus
                      server_ptr server,
                      interpreter_ptr p_interpreter,
                      history_manager_ptr p_history_manager,
-                     debugger_ptr debugger,
-                     nl::json::error_handler_t eh);
+                     debugger_ptr debugger);
 
         ~xkernel_core();
 
@@ -132,8 +131,6 @@ namespace xeus
 
         std::array<guid_list, 2> m_parent_id;
         std::array<nl::json, 2> m_parent_header;
-
-        nl::json::error_handler_t m_error_handler;
     };
 }
 
