@@ -13,15 +13,14 @@
 
 #include "nlohmann/json.hpp"
 
-#include "test_interpreter.hpp"
+#include "xmock_interpreter.hpp"
+#include "xmock_server.hpp"
 
 #include "xeus/xkernel.hpp"
-#include "xeus/xmiddleware.hpp"
 #include "xeus/xsystem.hpp"
 #include "xeus/xeus_context.hpp"
 #include "xeus/xhelper.hpp"
 #include "xeus/xkernel_configuration.hpp"
-#include "xeus/xserver_zmq.hpp"
 
 namespace nl = nlohmann;
 
@@ -31,14 +30,14 @@ namespace xeus
     {
         TEST_CASE("print_starting_message")
         {
-            auto context = make_context<zmq::context_t>();
+            auto context = make_empty_context();
 
-            using interpreter_ptr = std::unique_ptr<test_kernel::test_interpreter>;
-            interpreter_ptr interpreter = interpreter_ptr(new test_kernel::test_interpreter());
+            using interpreter_ptr = std::unique_ptr<xmock_interpreter>;
+            interpreter_ptr interpreter = interpreter_ptr(new xmock_interpreter());
             xkernel kernel(get_user_name(),
                          std::move(context),
                          std::move(interpreter),
-                         make_xserver_zmq);
+                         make_mock_server);
             std::string kernel_config = print_starting_message(kernel.get_config());
             std::cout << kernel_config << std::endl;
             size_t pos = kernel_config.find("Starting kernel...\n"
@@ -77,13 +76,6 @@ namespace xeus
             REQUIRE_NE(username, "unspecified user");
         }
 
-        TEST_CASE("find_free_port")
-        {
-            std::string port = find_free_port();
-            REQUIRE_NE(port, "");
-            REQUIRE_EQ(port.length(), std::size_t(5));
-        }
-
         TEST_CASE("temp_directory_path")
         {
             std::string path = get_temp_directory_path();
